==> igniteui-react-charts-16.6.8.tgz: package/ES5/igr-assigning-category-marker-style-event-args.js <==
import * as tslib_1 from "tslib";
import { AssigningCategoryStyleEventArgsBase } from "./igr-assigning-category-style-event-args-base";
import { AssigningCategoryMarkerStyleEventArgs as AssigningCategoryMarkerStyleEventArgs_internal } from "./AssigningCategoryMarkerStyleEventArgs";
/**
 * Represents event arguments class for the AssigningCategoryStyleEvent
*
* The `assigningCategoryMarkerStyle` event fired to allow you to override the style of markers for the items in a category or financial series.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*     <IgrCategoryXAxis name="xAxis" label="Year" />
*     <IgrNumericYAxis  name="yAxis" />
*
*     <IgrRangeColumnSeries
*         name="series1"
*         xAxisName="xAxis"
*         yAxisName="yAxis"
*         highMemberPath="High"
*         lowMemberPath="Low" />
*  </IgrDataChart>
* ```
*
* ```ts
* series.assigningCategoryMarkerStyle= this.chart_assigningCategoryMarkerStyle;
* chart_assigningCategoryMarkerStyle(sender :any,args: assigningCategoryMarkerStyle )
*   {
*
*
*   }
* ```
*/
var AssigningCategoryMarkerStyleEventArgs = /** @class */ (function (_super) {
    tslib_1.__extends(AssigningCategoryMarkerStyleEventArgs, _super);
    function AssigningCategoryMarkerStyleEventArgs() {
        return _super.call(this) || this;
    }
    AssigningCategoryMarkerStyleEventArgs.prototype.createImplementation = function () {
        return new AssigningCategoryMarkerStyleEventArgs_internal();
    };
    Object.defineProperty(AssigningCategoryMarkerStyleEventArgs.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    return AssigningCategoryMarkerStyleEventArgs;
}(AssigningCategoryStyleEventArgsBase));
export { AssigningCategoryMarkerStyleEventArgs };

==> igniteui-react-charts-16.11.1.tgz: package/ES5/igr-assigning-category-marker-style-event-args.js <==
import * as tslib_1 from "tslib";
import { AssigningCategoryStyleEventArgsBase } from "./igr-assigning-category-style-event-args-base";
import { AssigningCategoryMarkerStyleEventArgs as AssigningCategoryMarkerStyleEventArgs_internal } from "./AssigningCategoryMarkerStyleEventArgs";
/**
 * Represents event arguments class for the AssigningCategoryStyleEvent
*
* The `assigningCategoryMarkerStyle` event fired to allow you to override the style of markers for the items in a category or financial series.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*     <IgrCategoryXAxis name="xAxis" label="Year" />
*     <IgrNumericYAxis  name="yAxis" />
*
*     <IgrRangeColumnSeries
*         name="series1"
*         xAxisName="xAxis"
*         yAxisName="yAxis"
*         highMemberPath="High"
*         lowMemberPath="Low"
* 		isCustomCategoryStyleAllowed="true"
* 		assigningCategoryMarkerStyle= {this.onAssigningCategoryMarkerStyle} />
*  </IgrDataChart>
* ```
*
* ```ts
* series1.assigningCategoryMarkerStyle= this.onAssigningCategoryMarkerStyle ;
* public onAssigningCategoryMarkerStyle =( s:IgrCategorySeries, e: AssigningCategoryStyleEventArgs) => {
*
* }
* ```
*/
var AssigningCategoryMarkerStyleEventArgs = /** @class */ (function (_super) {
    tslib_1.__extends(AssigningCategoryMarkerStyleEventArgs, _super);
    function AssigningCategoryMarkerStyleEventArgs() {
        return _super.call(this) || this;
    }
    AssigningCategoryMarkerStyleEventArgs.prototype.createImplementation = function () {
        return new AssigningCategoryMarkerStyleEventArgs_internal();
    };
    Object.defineProperty(AssigningCategoryMarkerStyleEventArgs.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    return AssigningCategoryMarkerStyleEventArgs;
}(AssigningCategoryStyleEventArgsBase));
export { AssigningCategoryMarkerStyleEventArgs };
